@@ -38,6 +38,61 @@ For more information, please refer to <https://unlicense.org>
 """
 
 _spotlight_vulnerabilities_endpoints = [
+  [
+    "combinedQueryVulnerabilities",
+    "GET",
+    "/spotlight/combined/vulnerabilities/v1",
+    "Search for Vulnerabilities in your environment by providing an FQL filter and paging details. "
+    "Returns a set of Vulnerability entities which match the filter criteria",
+    "spotlight_vulnerabilities",
+    [
+      {
+        "type": "string",
+        "description": "A pagination token used with the `limit` parameter to manage pagination of results. "
+        "On your first request, don't provide an `after` token. On subsequent requests, provide the `after` "
+        "token from the previous response to continue from that place in the results.",
+        "name": "after",
+        "in": "query"
+      },
+      {
+        "maximum": 5000,
+        "minimum": 1,
+        "type": "integer",
+        "description": "The number of items to return in this response (default: 100, max: 5000). "
+        "Use with the after parameter to manage pagination of results.",
+        "name": "limit",
+        "in": "query"
+      },
+      {
+        "type": "string",
+        "description": "Sort vulnerabilities by their properties. Common sort options "
+        "include:\n\n<ul><li>created_timestamp|desc</li><li>closed_timestamp|asc</li></ul>",
+        "name": "sort",
+        "in": "query"
+      },
+      {
+        "type": "string",
+        "description": "Filter items using a query in Falcon Query Language (FQL). "
+        "Wildcards * are unsupported. \n\nCommon filter options include:\n\n<ul>"
+        "<li>created_timestamp:>'2019-11-25T22:36:12Z'</li><li>closed_timestamp:>'2019-11-25T22:36:12Z'</li>"
+        "<li>aid:'8e7656b27d8c49a34a1af416424d6231'</li></ul>",
+        "name": "filter",
+        "in": "query",
+        "required": True
+      },
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "csv",
+        "description": "Select various details blocks to be returned for each vulnerability entity. "
+        "Supported values:\n\n<ul><li>host_info</li><li>remediation_details</li><li>cve_details</li></ul>",
+        "name": "facet",
+        "in": "query"
+      }
+    ]
+  ],
   [
     "getRemediationsV2",
     "GET",
