@@ -84,7 +84,7 @@ def validate_payload(validator: dict, params: dict, required: list = None) -> bo
 
 def parse_id_list(id_list) -> str:
     """Converts a list of IDs to a comma-delimited string."""
-    if isinstance(id_list, list):
+    if isinstance(id_list, list):  # pragma: no cover   DEPRECATING - jshcodes@CrowdStrike
         returned = ""
         for string in id_list:
             if len(returned) > 1:
